@@ -89,6 +89,11 @@ func httpNoBody(m dsl.Matcher) {
 		Where(m["nil"].Text == "nil").
 		Suggest("http.NewRequestWithContext($ctx, $method, $url, http.NoBody)").
 		Report("http.NoBody should be preferred to the nil request body")
+
+	m.Match("httptest.NewRequest($method, $url, $nil)").
+		Where(m["nil"].Text == "nil").
+		Suggest("httptest.NewRequest($method, $url, http.NoBody)").
+		Report("http.NoBody should be preferred to the nil request body")
 }
 
 //doc:summary Detects expressions like []rune(s)[0] that may cause unwanted rune slice allocation
@@ -103,7 +108,7 @@ func preferDecodeRune(m dsl.Matcher) {
 }
 
 //doc:summary Detects usage of `len` when result is obvious or doesn't make sense
-//doc:tags    style
+//doc:tags    diagnostic
 //doc:before  len(arr) <= 0
 //doc:after   len(arr) == 0
 func sloppyLen(m dsl.Matcher) {
@@ -155,10 +160,16 @@ func emptyStringTest(m dsl.Matcher) {
 	m.Match(`len($s) != 0`).
 		Where(m["s"].Type.Is(`string`)).
 		Report("replace `$$` with `$s != \"\"`")
+	m.Match(`len($s) > 0`).
+		Where(m["s"].Type.Is(`string`)).
+		Report("replace `$$` with `$s != \"\"`")
 
 	m.Match(`len($s) == 0`).
 		Where(m["s"].Type.Is(`string`)).
 		Report("replace `$$` with `$s == \"\"`")
+	m.Match(`len($s) <= 0`).
+		Where(m["s"].Type.Is(`string`)).
+		Report("replace `$$` with `$s == \"\"`")
 }
 
 //doc:summary Detects redundant conversions between string and []byte
@@ -712,14 +723,14 @@ func badSorting(m dsl.Matcher) {
 		Report(`suspicious sort.StringSlice usage, maybe sort.Strings was intended?`)
 }
 
-//doc:summary Detects suspicious reassigment of error from another package
+//doc:summary Detects suspicious reassignment of error from another package
 //doc:tags    diagnostic experimental
 //doc:before  io.EOF = nil
 //doc:after   /* don't do it */
 func externalErrorReassign(m dsl.Matcher) {
 	m.Match(`$pkg.$err = $x`).
 		Where(m["err"].Type.Is(`error`) && m["pkg"].Object.Is(`PkgName`)).
-		Report(`suspicious reassigment of error from another package`)
+		Report(`suspicious reassignment of error from another package`)
 }
 
 //doc:summary Detects suspicious empty declarations blocks
@@ -780,26 +791,16 @@ func uncheckedInlineErr(m dsl.Matcher) {
 		At(m["err"])
 }
 
-//doc:summary Detects unsupported test and benchmark funcs
+//doc:summary Detects bad usage of sync.OnceFunc
 //doc:tags    diagnostic experimental
-//doc:before  func TessstUnit(t *testing.T)
-//doc:after   func TestUnit(t *testing.T)
-func sloppyTestFuncName(m dsl.Matcher) {
-	m.Match(`func $test($_ *testing.T) { $*_ }`).
-		Where(!m["test"].Text.Matches("Test.*") &&
-			!m["test"].Text.Matches("test.*")).
-		Report("function $test should be of form TestXXX(t *testing.T)")
+//doc:before  sync.OnceFunc(foo)()
+//doc:after   fooOnce := sync.OnceFunc(foo); ...; fooOnce()
+func badSyncOnceFunc(m dsl.Matcher) {
+	m.Match(`$*_; sync.OnceFunc($x); $*_;`).
+		Report("possible sync.OnceFunc misuse, sync.OnceFunc($x) result is not used").
+		Where(m.GoVersion().GreaterEqThan("1.21"))
 
-	m.Match(`func $bench($_ *testing.B) { $*_ }`).
-		Where(!m["bench"].Text.Matches("Benchmark.*") &&
-			!m["bench"].Text.Matches("bench.*")).
-		Report("function $bench should be of form BenchmarkXXX(b *testing.B)")
-
-	m.Match(`func $test($_ *testing.T) { $*_ }`).
-		Where(m["test"].Text.Matches("^test.*")).
-		Report("function $test looks like a test helper, consider to change 1st param to 'tb testing.TB'")
-
-	m.Match(`func $bench($_ *testing.B) { $*_ }`).
-		Where(m["bench"].Text.Matches("^bench(mark)?.*")).
-		Report("function $bench looks like a benchmark helper, consider to change 1st param to 'tb testing.TB'")
+	m.Match(`sync.OnceFunc($x)()`).
+		Report("possible sync.OnceFunc misuse, consider to assign sync.OnceFunc($x) to a variable").
+		Where(m.GoVersion().GreaterEqThan("1.21"))
 }
